@@ -56,7 +56,7 @@
 *            if INFORM = 2, N > 20 or N < 1.
 *
       EXTERNAL MVNFNC
-      INTEGER N, NL, M, INFIN(*), LENWRK, MAXPTS, INFORM, INFIS,
+      INTEGER I, N, NL, M, INFIN(*), LENWRK, MAXPTS, INFORM, INFIS,
      &     RULCLS, TOTCLS, NEWCLS, MAXCLS
       DOUBLE PRECISION 
      &     CORREL(*), LOWER(*), UPPER(*), ABSEPS, RELEPS, ERROR, VALUE,
